function coefficient = PLS_calc(x,Fs,low,high,islinear)
%input: x: timeseries, x must not be filtered
%       Fs: Frequency
%       low: low cut
%       high: high cut
%       islinear: 1: linear regression coefficient 0: power-law slope
%       isrank: 1: rank based 2: normal
%output: coefficient: rank regression coefficient / power-law of signal power
%

N = length(x);
xdft = fft(x);
xdft = abs(xdft(1:N/2+1));
freq = [0.0001,Fs/length(x):Fs/length(x):Fs/2]; % 0.0001 to avoid 0
pos_low = min(find(freq>=low));
pos_high = max(find(freq<=high));
xdft = xdft(pos_low:pos_high);
freq_x = freq(pos_low:pos_high);
Y = xdft/mean(xdft);

if islinear ==1
    X = [freq_x',ones(length(xdft),1)];
    b = rp_regress_ss(Y,X);
    coefficient = b(1);
else
    slope = rest_logfit(freq_x,Y);
    coefficient = slope;
end
